==> KleckFiles(3.03.1).zip: KleckFiles/report/reportdata_images.js <==
// pDate = date published in KR
// wDate = actual date released on web

var reportdata_images = [
{type:"images",
 tab: "Vatican",
 title: "The Vatican folder",
 desc: "What Jonathan has been show in the Vatican is incredible to say the least."
   +" The largest church in the world that calls itself Christian worship inside"
   +" of buildings in the shape of serpents; They sing in latin to Lucifier;"
   +" Carvings of bugs, dragons, owls, queen of heaven; Alters of genitals &amp; dead sheep; Reptiles birthing from the pit they call Jesus;"
   +" .. Go watch the videos. It's all on record and now proven."
   +" Everything is coming to light.",
 bible1: "luke 12:2|Luke 12:2-3"
   +"|<sup>2</sup> For there is nothing covered, that shall not be revealed; neither hid, that shall not be known."
   +"|<sup>3</sup> Therefore whatsoever ye have spoken in darkness shall be heard in the light; and that which ye have spoken in the ear in closets shall be proclaimed upon the housetops.",
  
 // ["SNlink|linktext|Text", img1, img2 ...]
 image1: ["/3797/category/330|Album: Illuminati|Vatican city: Paul VI Audience Hall (Hall of the Pontifical Audiences)",
   "/3797/category/330|2020/01/24/20200124224205-d179f4c5.jpg",
	"/27645/category/330|2021/10/25/20211025092207-10ac22cf.jpg",
	"/27644/category/330|2021/10/25/20211025092154-cd996979.jpg",
	"/27631/category/330|2021/10/24/20211024203545-a958bd3a.png",
	"/27649/category/330|2021/10/25/20211025092308-a9fb19f0.jpg"
	],
 image2: ["/24930/category/282|Album: Vatican|More Vatican images",
	"/25069/category/282|2021/01/14/20210114165552-bee2835f.png",
	"/24936/category/282|2020/12/29/20201229072248-7519efa4.png",
	"/3476/category/282|2020/01/24/20200124222332-40af8bc9.jpg",
	"/24944/category/282|2020/12/29/20201229072326-504f7b26.png",
   "/24930/category/282|2020/12/29/20201229072226-6d456496.png",
	"/24932/category/282|2020/12/29/20201229072232-e69a5814.png",
	"/24951/category/282|2020/12/29/20201229072357-d9e4a9f4.png"
   ]
},
	
{type:"images",
 tab: "Image Galleries",
 title: "Jonathan Kleck's Image Galleries",
 desc: "These image galleries contain over 50,000 images. They show you"
    +" how santas inverted hidden world manifests all around us. "
    +" In movies, books, artwork, media, history, signage. The twin system has been in our face the whole time. Sometimes you just need to invert the image to see the hidden meaning. "
    +" Sometimes you need to pray about it as you can see something in the shadow art but not sure what. And sometimes you need a guide like JK who has God given super vision.",
 desc2: '<ul>'
     +'<li><a href="shownotes1.html" target="_blank">Gallery 1 (downloadable KleckFiles.com site)</a></li>'
     +'<li><a href="shownotes2.html" target="_blank">Gallery 2 (downloadable KleckFiles.com site)</a></li>'
  
     +'<br><li><a href="https://www.show-notes.info/thisisit4321/gallery3/index.php/" target="_blank">Gallery 1 (Jonathan\'s website)</a></li>'
     +'<li><a href="https://www.show-notes.info/thisistheend/" target="_blank">Gallery 2 (Jonathan\'s website)</a></li>'
     +'</ul>',
     
 desc3: "<h3>Jonathan talks about his spiritual gift of sight</h3>",
 videoList: ['180307-01']
},
{type:"images",
 tab: "Illuminati Symbols",
 title: "Basic Illuminati Symbols",
 videoList: ['130708', '130709', '130710', '130712', '130714-01', '130718']
}
	
];

==> KleckFiles(5.80.00).zip: KleckFiles/report/reportdata_images.js <==
// pDate = date published in KR
// wDate = actual date released on web

var reportdata_images = [
{type:"images",
 tab: "Vatican",
 title: "The Vatican folder",
 desc: "What Jonathan has been show in the Vatican is incredible to say the least."
   +" The largest church in the world that calls itself Christian worship inside"
   +" of buildings in the shape of serpents; They sing in latin to Lucifier;"
   +" Carvings of bugs, dragons, owls, queen of heaven; Alters of genitals &amp; dead sheep; Reptiles birthing from the pit they call Jesus;"
   +" .. Go watch the videos. It's all on record and now proven."
   +" Everything is coming to light.",
 bible1: "luke 12:2|Luke 12:2-3"
   +"|<sup>2</sup> For there is nothing covered, that shall not be revealed; neither hid, that shall not be known."
   +"|<sup>3</sup> Therefore whatsoever ye have spoken in darkness shall be heard in the light; and that which ye have spoken in the ear in closets shall be proclaimed upon the housetops.",
  
 // ["SNlink|linktext|Text", img1, img2 ...]
 image1: ["/3797/category/330|Album: Illuminati|Vatican city: Paul VI Audience Hall (Hall of the Pontifical Audiences)",
   "/3797/category/330|2020/01/24/20200124224205-d179f4c5.jpg",
	"/27645/category/330|2021/10/25/20211025092207-10ac22cf.jpg",
	"/27644/category/330|2021/10/25/20211025092154-cd996979.jpg",
	"/27631/category/330|2021/10/24/20211024203545-a958bd3a.png",
	"/27649/category/330|2021/10/25/20211025092308-a9fb19f0.jpg"
	],
 image2: ["/24930/category/282|Album: Vatican|More Vatican images",
	"/25069/category/282|2021/01/14/20210114165552-bee2835f.png",
	"/24936/category/282|2020/12/29/20201229072248-7519efa4.png",
	"/3476/category/282|2020/01/24/20200124222332-40af8bc9.jpg",
	"/24944/category/282|2020/12/29/20201229072326-504f7b26.png",
   "/24930/category/282|2020/12/29/20201229072226-6d456496.png",
	"/24932/category/282|2020/12/29/20201229072232-e69a5814.png",
	"/24951/category/282|2020/12/29/20201229072357-d9e4a9f4.png"
   ]
},
	
{type:"images",
 tab: "Image Galleries",
 title: "Jonathan Kleck's Image Galleries",
 desc: "These image galleries contain over 50,000 images. They show you"
    +" how santas inverted hidden world manifests all around us. "
    +" In movies, books, artwork, media, history, signage. The twin system has been in our face the whole time. Sometimes you just need to invert the image to see the hidden meaning. "
    +" Sometimes you need to pray about it as you can see something in the shadow art but not sure what. And sometimes you need a guide like JK who has God given super vision.",
 desc2: '<ul>'
     +'<li><a href="shownotes1.html" target="_blank">Gallery 1 (downloadable KleckFiles.com site)</a></li>'
     +'<li><a href="shownotes2.html" target="_blank">Gallery 2 (downloadable KleckFiles.com site)</a></li>'
  
     +'<br><li>Jonathan Kleck\'s Gallery 1 site no longer exists. Most images have been transfered into Gallery 2.</li>'
     +'<li><a href="https://www.show-notes.net/thisistheend/" target="_blank">Gallery 2 (Jonathan\'s website)</a></li>'
     +'</ul>',
     
 desc3: "<h3>Jonathan talks about his spiritual gift of sight</h3>",
 videoList: ['180307-01']
},
{type:"images",
 tab: "Illuminati Symbols",
 title: "Basic Illuminati Symbols",
 videoList: ['130708', '130709', '130710', '130712', '130714-01', '130718']
}
	
];
